Class: Buildr::AS3::Compiler::AirMxmlc
- Inherits:
-
Mxmlc
- Object
- Compiler::Base
- FlexCompilerBase
- Mxmlc
- Buildr::AS3::Compiler::AirMxmlc
- Defined in:
- lib/buildr/as3/compiler/airmxmlc.rb
Overview
AirMxmlc compiler:
compile.using(:airmxmlc)
Accepts the following options:
- :main -- Pass the absolute path to the .as/.mxml file you want to have as your main-/document-class (you can use )
- :warnings -- Issue warnings when compiling. Defaults to "true"
- :debug -- Generates bytecode with debugging information. Set from the debug environment variable/global option.
- :flexsdk -- Specify an FlexSDK Artifact of the type Buildr::AS3::Flex::FlexSDK
- :apparat -- Specify an Apparat Artifact of the type Buildr::AS3::Apparat::ApparatToolkit (this is only necessary if you want to make use of the apparat-toolkit)
- :other -- Array of options passed to the compiler (e.g. ['-compiler.incremental=true', '-static-link-runtime-shared-libraries=true', '-optimize'])
Constant Summary
Constants inherited from FlexCompilerBase
FlexCompilerBase::COMPILE_OPTIONS
Instance Method Summary collapse
Methods inherited from FlexCompilerBase
Constructor Details
This class inherits a constructor from Buildr::AS3::Compiler::FlexCompilerBase
Instance Method Details
#compile(sources, target, dependencies) ⇒ Object
:nodoc:
47 48 49 50 |
# File 'lib/buildr/as3/compiler/airmxmlc.rb', line 47 def compile(sources, target, dependencies) #:nodoc: @air = true super end |