Class: Buildr::AS3::Compiler::Mxmlc
- Inherits:
-
FlexCompilerBase
- Object
- Compiler::Base
- FlexCompilerBase
- Buildr::AS3::Compiler::Mxmlc
- Defined in:
- lib/buildr/as3/compiler/mxmlc.rb
Overview
Mxmlc compiler:
compile.using(:mxmlc)
Used by default if .as or .mxml files are found in the src/main/as3 directory (or src/test/as3) and sets the target directory to target/bin (or target/test/bin).
Accepts the following options:
- :main -- Pass the absolute path to the .as/.mxml file you want to have as your main-/document-class (you can use )
- :warnings -- Issue warnings when compiling. Defaults to "true"
- :debug -- Generates bytecode with debugging information. Set from the debug environment variable/global option.
- :flexsdk -- Specify an FlexSDK Artifact of the type Buildr::AS3::Flex::FlexSDK
- :apparat -- Specify an Apparat Artifact of the type Buildr::AS3::Apparat::ApparatToolkit (this is only necessary if you want to make use of the apparat-toolkit)
- :other -- Array of options passed to the compiler (e.g. ['-compiler.incremental=true', '-static-link-runtime-shared-libraries=true', '-optimize'])
Direct Known Subclasses
Constant Summary
Constants inherited from FlexCompilerBase
FlexCompilerBase::COMPILE_OPTIONS
Instance Method Summary collapse
Methods inherited from FlexCompilerBase
Constructor Details
This class inherits a constructor from Buildr::AS3::Compiler::FlexCompilerBase
Instance Method Details
#compile(sources, target, dependencies) ⇒ Object
:nodoc:
49 50 51 52 53 54 |
# File 'lib/buildr/as3/compiler/mxmlc.rb', line 49 def compile(sources, target, dependencies) #:nodoc: @compiler_jar = [:flexsdk].mxmlc_jar COMPILE_OPTIONS << :main @main = [:main] super end |